==> igniteui-react-core-18.2.0-beta.0.tgz: package/esm5/lib/WebPivotGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotGridDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridDescription, _super);
    function WebPivotGridDescription() {
        var _this = _super.call(this) || this;
        _this.hv = null;
        _this.hd = null;
        _this.hg = false;
        _this.hh = false;
        _this.hl = null;
        _this.hf = false;
        _this.hq = null;
        _this.hm = null;
        _this.hu = null;
        _this.hs = null;
        _this.hp = null;
        _this.hr = null;
        _this.hw = null;
        _this.ht = null;
        _this.hx = null;
        return _this;
    }
    WebPivotGridDescription.prototype.get_type = function () {
        return "WebPivotGrid";
    };
    Object.defineProperty(WebPivotGridDescription.prototype, "valueChipTemplateRef", {
        get: function () {
            return this.hv;
        },
        set: function (a) {
            this.hv = a;
            this.g("ValueChipTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "pivotConfiguration", {
        get: function () {
            return this.hd;
        },
        set: function (a) {
            this.hd = a;
            this.g("PivotConfiguration");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "showPivotConfigurationUI", {
        get: function () {
            return this.hg;
        },
        set: function (a) {
            this.hg = a;
            this.g("ShowPivotConfigurationUI");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "superCompactMode", {
        get: function () {
            return this.hh;
        },
        set: function (a) {
            this.hh = a;
            this.g("SuperCompactMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionDataColumns", {
        get: function () {
            return this.hl;
        },
        set: function (a) {
            this.hl = a;
            this.g("DimensionDataColumns");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "defaultExpandState", {
        get: function () {
            return this.hf;
        },
        set: function (a) {
            this.hf = a;
            this.g("DefaultExpandState");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dataRef", {
        get: function () {
            return this.hq;
        },
        set: function (a) {
            this.hq = a;
            this.g("DataRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "filteredData", {
        get: function () {
            return this.hm;
        },
        set: function (a) {
            this.hm = a;
            this.g("FilteredData");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "emptyPivotGridTemplateRef", {
        get: function () {
            return this.hu;
        },
        set: function (a) {
            this.hu = a;
            this.g("EmptyPivotGridTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionsChangeRef", {
        get: function () {
            return this.hs;
        },
        set: function (a) {
            this.hs = a;
            this.g("DimensionsChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "configurationChangeRef", {
        get: function () {
            return this.hp;
        },
        set: function (a) {
            this.hp = a;
            this.g("ConfigurationChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionInitRef", {
        get: function () {
            return this.hr;
        },
        set: function (a) {
            this.hr = a;
            this.g("DimensionInitRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "valueInitRef", {
        get: function () {
            return this.hw;
        },
        set: function (a) {
            this.hw = a;
            this.g("ValueInitRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionsSortingExpressionsChangeRef", {
        get: function () {
            return this.ht;
        },
        set: function (a) {
            this.ht = a;
            this.g("DimensionsSortingExpressionsChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "valuesChangeRef", {
        get: function () {
            return this.hx;
        },
        set: function (a) {
            this.hx = a;
            this.g("ValuesChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    WebPivotGridDescription.$t = markType(WebPivotGridDescription, 'WebPivotGridDescription', WebGridBaseDirectiveDescription.$);
    return WebPivotGridDescription;
}(WebGridBaseDirectiveDescription));
export { WebPivotGridDescription };

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm5/lib/WebPivotGridDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebGridBaseDirectiveDescription } from "./WebGridBaseDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPivotGridDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridDescription, _super);
    function WebPivotGridDescription() {
        var _this = _super.call(this) || this;
        _this.g4 = null;
        _this.g3 = null;
        _this.gn = null;
        _this.gr = false;
        _this.gp = null;
        _this.gt = false;
        _this.gs = false;
        _this.gx = null;
        _this.g1 = null;
        _this.gz = null;
        _this.g2 = null;
        _this.gy = null;
        _this.g5 = null;
        _this.g0 = null;
        _this.g6 = null;
        return _this;
    }
    WebPivotGridDescription.prototype.get_type = function () {
        return "WebPivotGrid";
    };
    Object.defineProperty(WebPivotGridDescription.prototype, "valueChipTemplateRef", {
        get: function () {
            return this.g4;
        },
        set: function (a) {
            this.g4 = a;
            this.g("ValueChipTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "rowDimensionHeaderTemplateRef", {
        get: function () {
            return this.g3;
        },
        set: function (a) {
            this.g3 = a;
            this.g("RowDimensionHeaderTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "pivotConfiguration", {
        get: function () {
            return this.gn;
        },
        set: function (a) {
            this.gn = a;
            this.g("PivotConfiguration");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "autoGenerateConfig", {
        get: function () {
            return this.gr;
        },
        set: function (a) {
            this.gr = a;
            this.g("AutoGenerateConfig");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "pivotUI", {
        get: function () {
            return this.gp;
        },
        set: function (a) {
            this.gp = a;
            this.g("PivotUI");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "superCompactMode", {
        get: function () {
            return this.gt;
        },
        set: function (a) {
            this.gt = a;
            this.g("SuperCompactMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "defaultExpandState", {
        get: function () {
            return this.gs;
        },
        set: function (a) {
            this.gs = a;
            this.g("DefaultExpandState");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dataRef", {
        get: function () {
            return this.gx;
        },
        set: function (a) {
            this.gx = a;
            this.g("DataRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "emptyPivotGridTemplateRef", {
        get: function () {
            return this.g1;
        },
        set: function (a) {
            this.g1 = a;
            this.g("EmptyPivotGridTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionsChangeRef", {
        get: function () {
            return this.gz;
        },
        set: function (a) {
            this.gz = a;
            this.g("DimensionsChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "pivotConfigurationChangeRef", {
        get: function () {
            return this.g2;
        },
        set: function (a) {
            this.g2 = a;
            this.g("PivotConfigurationChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionInitRef", {
        get: function () {
            return this.gy;
        },
        set: function (a) {
            this.gy = a;
            this.g("DimensionInitRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "valueInitRef", {
        get: function () {
            return this.g5;
        },
        set: function (a) {
            this.g5 = a;
            this.g("ValueInitRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "dimensionsSortingExpressionsChangeRef", {
        get: function () {
            return this.g0;
        },
        set: function (a) {
            this.g0 = a;
            this.g("DimensionsSortingExpressionsChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPivotGridDescription.prototype, "valuesChangeRef", {
        get: function () {
            return this.g6;
        },
        set: function (a) {
            this.g6 = a;
            this.g("ValuesChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    WebPivotGridDescription.$t = markType(WebPivotGridDescription, 'WebPivotGridDescription', WebGridBaseDirectiveDescription.$);
    return WebPivotGridDescription;
}(WebGridBaseDirectiveDescription));
export { WebPivotGridDescription };
